<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>Data::SyncthingLauncher</name>
    <message>
        <location filename="../misc/syncthinglauncher.cpp" line="151"/>
        <source>Not built with libsyncthing support.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui</name>
    <message>
        <location filename="../webview/webviewdialog.cpp" line="249"/>
        <source>Unable to open Syncthing UI via &quot;%1&quot;: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="89"/>
        <source>The network connection is currently considered metered.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="90"/>
        <source>The network connection is currently not considered metered.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="91"/>
        <source>Unable to determine whether the network connection is metered; assuming an unmetered connection.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::AppearanceOptionPage</name>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="12"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="274"/>
        <source>x: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="296"/>
        <source>y: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="134"/>
        <source>Menu size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="149"/>
        <location filename="../settings/appearanceoptionpage.ui" line="187"/>
        <location filename="../settings/appearanceoptionpage.ui" line="271"/>
        <location filename="../settings/appearanceoptionpage.ui" line="293"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="171"/>
        <source> x </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="221"/>
        <source>Optional GUI elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="334"/>
        <source>Traffic statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="28"/>
        <source>Frame shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="42"/>
        <source>No frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="47"/>
        <source>Box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="52"/>
        <source>Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="57"/>
        <source>Styled panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="65"/>
        <source>Frame shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="79"/>
        <source>Plain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="84"/>
        <source>Raised</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="89"/>
        <source>Sunken</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="97"/>
        <source>Tab position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="111"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="116"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="121"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="126"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="228"/>
        <source>Positioning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="240"/>
        <source>Use cursor position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="250"/>
        <source>Otherwise assume tray icon coordinates to be:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="341"/>
        <source>Show tab texts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="355"/>
        <source>Prefer icons from theme over ForkAwesome icons (needs restart to apply)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="364"/>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="378"/>
        <source>Popup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="383"/>
        <source>Normal window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="388"/>
        <source>Window without titlebar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="393"/>
        <source>None - open Syncthing directly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="401"/>
        <source>Window type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::ApplyWizardPage</name>
    <message>
        <location filename="../settings/applywizardpage.ui" line="6"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="911"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="912"/>
        <source>Apply selected configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="913"/>
        <source>Review the summary of the configuration changes before applying them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="937"/>
        <source>Summary:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="951"/>
        <source>Keep %1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="951"/>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="951"/>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="952"/>
        <source>%1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="952"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="952"/>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="962"/>
        <source>Keep connection and launcher configuration as-is</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="965"/>
        <source>Configure Syncthing Tray to use the currently running Syncthing instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="966"/>
        <source>Do &lt;i&gt;not&lt;/i&gt; change how Syncthing is launched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="970"/>
        <source>Start Syncthing via Syncthing Tray&apos;s launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="972"/>
        <source>executable from PATH as separate process, &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="973"/>
        <source>built-in Syncthing library, &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="978"/>
        <source>Start Syncthing by enabling and starting its systemd unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="980"/>
        <source>Using user unit &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="981"/>
        <source>Using system unit &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="990"/>
        <source>systemd integration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="996"/>
        <source>Preserve existing autostart entry for &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1002"/>
        <source>Override</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1002"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1003"/>
        <source>%1 existing autostart entry for &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1005"/>
        <source>autostart of Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1010"/>
        <source>Further information:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1010"/>
        <source>Click on &quot;Show details from setup detection&quot; for further details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1011"/>
        <source>If you want to do amendments, you can head back one or more steps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1011"/>
        <source>If you abort now, nothing will be changed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::AutostartOptionPage</name>
    <message>
        <location filename="../settings/autostartoptionpage.ui" line="12"/>
        <source>Autostart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartoptionpage.ui" line="27"/>
        <source>Start the tray icon when the desktop environment launches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartoptionpage.ui" line="75"/>
        <source>Delete existing entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="817"/>
        <source>This is achieved by adding a *.desktop file under &lt;i&gt;~/.config/autostart&lt;/i&gt; so the setting only affects the current user.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="820"/>
        <source>This is achieved by adding a registry key under &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; so the setting only affects the current user. Note that the startup entry is invalidated when moving &lt;i&gt;syncthingtray.exe&lt;/i&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="824"/>
        <source>This is achieved by adding a *.plist file under &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; so the setting only affects the current user.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="828"/>
        <source>This feature has not been implemented for your platform (yet).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1036"/>
        <source>unable to modify startup entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1066"/>
        <source>There is already an autostart entry for &quot;%1&quot;. It will not be overridden when applying changes unless you delete it first.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::AutostartWizardPage</name>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="6"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="19"/>
        <source>Start Syncthing Tray on login (only affects sessions of the current user)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="46"/>
        <source>You previously selected to start Syncthing via the built-in launcher so Syncthing itself will be started automatically on login as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="56"/>
        <source>You previously selected to start Syncthing via systemd so its systemd-unit will be enabled. This means Syncthing itself will start automatically independently of this setting which only affects the tray icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="66"/>
        <source>Since Syncthing is running independently of Syncthing Tray on your system, this does not affect when Syncthing itself is launched.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="76"/>
        <source>The currently running Syncthing instance is started via Syncthing Tray so Syncthing itself will be started automatically on login as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="86"/>
        <source>This setting is about Syncthing Tray itself. If Syncthing is started via Syncthing Tray&apos;s launcher it will indirectly affect Syncthing as well, though.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="835"/>
        <source>Configure autostart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="836"/>
        <source>Select whether to start Syncthing Tray automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="890"/>
        <source>Do not modify the existing autostart entry for
&quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::BuiltinWebViewOptionPage</name>
    <message>
        <location filename="../settings/builtinwebviewoptionpage.ui" line="12"/>
        <location filename="../settings/settingsdialog.cpp" line="1651"/>
        <source>Built-in web view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/builtinwebviewoptionpage.ui" line="22"/>
        <source>Zoom factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/builtinwebviewoptionpage.ui" line="45"/>
        <source>Hiding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/builtinwebviewoptionpage.ui" line="52"/>
        <source>Keep web view running when currently not shown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1653"/>
        <source>Syncthing Tray has not been built with vieb view support utilizing either Qt WebKit or Qt WebEngine.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::ConnectionOptionPage</name>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="12"/>
        <source>Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="30"/>
        <source>Config label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="80"/>
        <source>Move currently selected configuration down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="97"/>
        <source>Move currently selected configuration up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="114"/>
        <source>Add secondary instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="131"/>
        <source>Remove currently selected secondary instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="161"/>
        <source>It is possible to save multiple configurations. This allows switching quickly between multiple Syncthing instances using the connection button in the right corner of the tray menu. The config label is an arbitrary name to identify a configuration and does not have to match the name of the corresponding Syncthing device. The first configuration is the primary/default configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="171"/>
        <source>Syncthing URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="185"/>
        <source>Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="202"/>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="219"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="512"/>
        <source>API key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="236"/>
        <source>HTTPS certificate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="178"/>
        <source>&quot;http://host:port/…&quot; or &quot;https://host:port/…&quot;, e.g. &quot;http://127.0.0.1:8384&quot; for local instance with default settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="192"/>
        <source>Supply credentials for HTTP authentication (normally the API key is sufficient)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="267"/>
        <source>Insert values from local Syncthing configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="311"/>
        <source>Poll interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="335"/>
        <source>Frequency for updating traffic statistics and download speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="338"/>
        <location filename="../settings/connectionoptionpage.ui" line="381"/>
        <location filename="../settings/connectionoptionpage.ui" line="410"/>
        <location filename="../settings/connectionoptionpage.ui" line="442"/>
        <location filename="../settings/connectionoptionpage.ui" line="539"/>
        <location filename="../settings/connectionoptionpage.ui" line="591"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="351"/>
        <source>Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="358"/>
        <source>Device statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="378"/>
        <source>Frequency for updating device statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="394"/>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="407"/>
        <source>Frequency to poll for new errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="423"/>
        <source>Reconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="436"/>
        <source>Time to wait for reconnecting again when the connection to Syncthing has been lost. This setting might be overruled by systemd and launcher settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="439"/>
        <source>no</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="471"/>
        <source>Overall status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="611"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="623"/>
        <source>Select what information should be considered to compute the overall status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="481"/>
        <source>Current status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="488"/>
        <source>disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="501"/>
        <source>Apply connection settings and try to reconnect with the currently selected config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="519"/>
        <source>The API key displayed in Syncthing&apos;s settings dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="526"/>
        <source>The timeout for normal requests to Syncthing&apos;s API. Set to zero to enforce no timeout.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="529"/>
        <source>Transfer timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="536"/>
        <source>no timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="568"/>
        <source>Show advanced configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="578"/>
        <source>The timeout for long-polling requests to Syncthing&apos;s event API. Set to zero to use Syncthing&apos;s default timeout and no timeout being enforced from Syncthing Tray&apos;s side.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="581"/>
        <source>Long polling int.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="588"/>
        <source>Syncthing&apos;s default with no timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="604"/>
        <source>Pause all devices while the local network connection is metered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="461"/>
        <source>Whether to connect automatically on startup. This setting might be overruled by systemd and launcher settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="464"/>
        <source>Connect automatically on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="127"/>
        <source>Auto-detected for local instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="284"/>
        <source>Select config file manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="171"/>
        <source>Select Syncthing config file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="179"/>
        <source>Unable to parse the Syncthing config file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="276"/>
        <source>Unable to load specified certificate &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="301"/>
        <source>Instance %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DBusStatusNotifier</name>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="25"/>
        <source> - internal error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="26"/>
        <source> - launcher error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="27"/>
        <source>Syncthing notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="29"/>
        <source> - new device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="30"/>
        <source> - new folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="33"/>
        <source>Disconnected from Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="34"/>
        <source>Try to reconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="38"/>
        <location filename="../misc/dbusstatusnotifier.cpp" line="42"/>
        <source>View details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="46"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="46"/>
        <source>Dismiss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="52"/>
        <source>Open web UI</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DetectionWizardPage</name>
    <message>
        <location filename="../settings/wizard.cpp" line="527"/>
        <source>Checking current Syncthing setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="528"/>
        <source>Checking Syncthing configuration and whether Syncthing is already running or can be started …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="534"/>
        <source>Check again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="586"/>
        <source>Re-visit setup detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="587"/>
        <source>You might trigger checking the Syncthing setup again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="613"/>
        <source>It looks like Syncthing has not been running on this system before as its configuration cannot be found. Is that correct?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="609"/>
        <source>Yes, continue configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="610"/>
        <source>No, let me select Syncthing&apos;s configuration file manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="619"/>
        <source>Select Syncthing&apos;s configuration file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::DirectoryErrorsDialog</name>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="28"/>
        <source>Errors for folder %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="46"/>
        <source>Remove non-empty directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/direrrorsdialog.cpp" line="83"/>
        <source>%1 item(s) out-of-sync</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="113"/>
        <source>Remove non-empty directories for folder &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="114"/>
        <source>Do you really want to remove the following directories:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="137"/>
        <source>Unable to remove the following dirs:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::FinalWizardPage</name>
    <message>
        <location filename="../settings/wizard.cpp" line="1070"/>
        <source>Waiting for configuration wizard completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1071"/>
        <source>Changes are being applied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1077"/>
        <source>Configuration wizard completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1081"/>
        <source>All changes have been applied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1083"/>
        <source>&lt;p&gt;The configuration has been changed successfully. The way Syncthing Tray connects to and starts Syncthing has not changed, though. You may configure this manually in the settings.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1086"/>
        <source>&lt;p&gt;The configuration has been changed successfully. You can close the wizard and &lt;a href=&quot;openSyncthing&quot;&gt;open Syncthing&lt;/a&gt; to pair remote devices and add folders for sharing. If you need further help, read the &lt;a href=&quot;openDocs&quot;&gt;documentation to get started&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;To initiate the pairing from another device, the device ID of this Syncthing device is displayed below.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1095"/>
        <source>Not all changes could be applied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1099"/>
        <source>You may try to head back one or more steps and try again or finish the wizard and configure Syncthing Tray manually.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::GeneralWebViewOptionPage</name>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="12"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="22"/>
        <source>Open Syncthing&apos;s UI via</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="28"/>
        <source>Syncthing Tray&apos;s built-in web view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="35"/>
        <source>Tab in the default web browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="50"/>
        <source>Chromium-based browser in &quot;app mode&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="57"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1627"/>
        <source>Custom command to launch Syncthing&apos;s UI - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1628"/>
        <source>&lt;p&gt;Enter a custom command to launch Syncthing&apos;s UI. The expression &lt;code&gt;%SYNCTHING_URL%&lt;/code&gt; will be replaced with the Syncthing-URL.&lt;/p&gt;&lt;p&gt;Leave the command empty to use the auto-detection.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::IconsOptionPage</name>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="12"/>
        <source>Icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="39"/>
        <source>Use Drag &amp; Drop to re-use a selected color at a different position.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="46"/>
        <source>Status icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="54"/>
        <source>Increase the rendering size if you&apos;re using a tray area with extraordinarily big icons.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="57"/>
        <source>Rendering size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="97"/>
        <source>? px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="106"/>
        <source>Stroke width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="113"/>
        <source>Thick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="131"/>
        <source>Background color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="141"/>
        <source>Background color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="151"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="164"/>
        <source>Foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="198"/>
        <source>Restore previous settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="209"/>
        <source>Use preset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::IconsOptionPageBase</name>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="639"/>
        <source>UI icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="645"/>
        <source>System icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="641"/>
        <source>These icon settings are used within Syncthing Tray&apos;s UI.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="646"/>
        <source>These icon settings are used for the system tray icon and the notifications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="648"/>
        <source>Use same settings as for UI icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="709"/>
        <source>Colorful background with gradient (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="714"/>
        <source>Transparent background and dark foreground (for bright themes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="719"/>
        <source>Transparent background and bright foreground (for dark themes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="735"/>
        <source>%1 px (scaled to %2 px)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::InternalErrorsDialog</name>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="27"/>
        <source>Internal errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="28"/>
        <source>Request URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="29"/>
        <source>Response:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="55"/>
        <source>Clear errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/internalerrorsdialog.cpp" line="117"/>
        <source>%1 error(s) occurred</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>QtGui::LauncherOptionPage</name>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="6"/>
        <source>Syncthing launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="21"/>
        <source>Launch Syncthing when starting the tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="43"/>
        <source>Syncthing executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="53"/>
        <source>Arguments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="63"/>
        <source>Use built-in Syncthing library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="73"/>
        <source>Config directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="83"/>
        <source>Log level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="91"/>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="96"/>
        <source>Verbose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="101"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="106"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="111"/>
        <source>Fatal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="70"/>
        <source>Set directory for configuration and keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="119"/>
        <source>Set database directory (falls back to config directory if empty)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="122"/>
        <source>Data directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="135"/>
        <source>Show start/stop button on tray for local instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="142"/>
        <source>Consider process status for notifications and reconnect attempts concerning local instance
 • Don&apos;t reconnect when the process is not running
 • Try to reconnect when starting the process
 • Suppress notification about disconnect when Syncthing has been stopped manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="152"/>
        <source>Stop automatically when network connection is metered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="179"/>
        <source>Syncthing log (interleaved stdout/stderr)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="192"/>
        <source>Apply and launch now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="209"/>
        <location filename="../settings/settingsdialog.cpp" line="1246"/>
        <source>Stop launched instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="228"/>
        <source>No log messages available yet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="235"/>
        <source>Ensure latest log is visible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1107"/>
        <source>%1-launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1108"/>
        <source>Launch %1 when starting the tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1111"/>
        <source>%1 executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1112"/>
        <source>%1 log (interleaved stdout/stderr)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1129"/>
        <source>Restore default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1135"/>
        <source>Show Syncthing releases/downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1281"/>
        <source>%1 exited with exit code %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1284"/>
        <source>%1 crashed with exit code %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1317"/>
        <source>failed to start (e.g. executable does not exist or not permission error)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1320"/>
        <source>process crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1323"/>
        <source>timeout error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1326"/>
        <source>read error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1329"/>
        <source>write error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1332"/>
        <source>unknown process error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1335"/>
        <source>An error occurred when running %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1388"/>
        <source>Kill launched instance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::MainConfigWizardPage</name>
    <message>
        <location filename="../settings/wizard.cpp" line="640"/>
        <source>Select what configuration to apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="641"/>
        <source>Something when wrong when checking the Syncthing setup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="642"/>
        <source>Show details from setup detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="718"/>
        <source>Systemd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="750"/>
        <source>&lt;b&gt;The Syncthing config could be located under &quot;%1&quot; but it seems invalid/incomplete.&lt;/b&gt; Hence Syncthing is assumed to be not running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="742"/>
        <source>Looks like Syncthing is not running yet. You can launch it via %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="742"/>
        <source> and </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="6"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="23"/>
        <source>Configure Syncthing Tray for currently running Syncthing instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="30"/>
        <source>Start installed Syncthing application via Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="37"/>
        <source>Start Syncthing application that is built into Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="44"/>
        <source>Start Syncthing via systemd user-unit (enables and starts the unit %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="51"/>
        <source>Start Syncthing via systemd system-unit (enables and starts the unit %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="58"/>
        <source>Keep settings for how to connect to Syncthing and start Syncthing as they are</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="65"/>
        <source>Enable systemd-integration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="92"/>
        <source>Click next to configure Syncthing Tray according to the selected options. You can also reconduct the checks the available options are based on by heading back. If you cancel the wizard, no configuration changes will be made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="691"/>
        <source>Looks like Syncthing is already running and Syncthing Tray can be configured accordingly automatically.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="725"/>
        <source>Syncthing Tray&apos;s launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="744"/>
        <source>Looks like Syncthing is not running yet and needs to be installed before Syncthing Tray can be configured.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::NotificationsOptionPage</name>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="6"/>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="16"/>
        <source>Notify on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="22"/>
        <source>disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="29"/>
        <source>internal errors (if disabled connection errors are only shown within &quot;Internal errors&quot; accessible from the menu!)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="36"/>
        <source>errors/notifications from Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="43"/>
        <source>sync of local folder complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="50"/>
        <source>sync of remote folder complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="57"/>
        <source>new/unknown device connects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="64"/>
        <source>remote device shares new/unknown folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="71"/>
        <source>errors of Syncthing launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="81"/>
        <source>Notification API</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="87"/>
        <source>D-Bus &amp;notifications (org.freedesktop.Notifications)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="94"/>
        <source>&amp;Method provided by Qt (might be overridden by QPA plugin)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="104"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="110"/>
        <source>Ignore inavailability of Syncthing the specified number of seconds after Syncthing has been started; has only effect if the Syncthing start can be determined which is currently only supported for the local instance started via Systemd or the internal launcher.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="120"/>
        <source>don&apos;t ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="123"/>
        <source> s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="484"/>
        <source>Configured to use D-Bus notifications but D-Bus notification daemon seems unavailabe.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::OtherDialogs</name>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="30"/>
        <source>Own device ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="40"/>
        <source>device ID is unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="48"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="85"/>
        <source>Remote/global tree of folder &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::SettingsDialog</name>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1702"/>
        <source>Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1710"/>
        <source>Web view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1717"/>
        <source>Startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1719"/>
        <source>additional tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1719"/>
        <source>Extra launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1742"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1748"/>
        <source>Start wizard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::StatusInfo</name>
    <message>
        <location filename="../misc/statusinfo.cpp" line="46"/>
        <source>Not connected to Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="49"/>
        <source>Trying to reconnect every %1 ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="18"/>
        <source>Initializing …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="44"/>
        <source>Connecting to Syncthing …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="55"/>
        <source>Reconnecting …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="62"/>
        <location filename="../misc/statusinfo.cpp" line="88"/>
        <source>Synchronization is ongoing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="63"/>
        <location filename="../misc/statusinfo.cpp" line="67"/>
        <source>At least one folder is out of sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="71"/>
        <source>Notifications available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="76"/>
        <source>Syncthing is idling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="80"/>
        <source>Syncthing is scanning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="84"/>
        <source>At least one device is paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="92"/>
        <source>At least one remote folder is not in sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="96"/>
        <source>Status is unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="119"/>
        <source>Not connected to other devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="143"/>
        <source>Connected to %1 devices</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="150"/>
        <source>Connected to %1 and %2</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="153"/>
        <source>Connected to %1</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>QtGui::SyncthingKiller</name>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="53"/>
        <source>The process %1 (PID: %2) has been requested to terminate but hasn&apos;t reacted yet. Kill the process?

This dialog closes automatically when the process finally terminates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="59"/>
        <source>Keep running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="60"/>
        <source>Kill process</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::SystemdOptionPage</name>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="6"/>
        <source>Systemd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="21"/>
        <source>Show start/stop button on tray for local instance when systemd is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="28"/>
        <source>Consider systemd unit status for notifications and reconnect attempts concerning local instance
 • Don&apos;t reconnect when unit not active/running
 • Try to reconnect when unit becomes active/running
 • Suppress notification about disconnect when Syncthing has been stopped manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="72"/>
        <source>Syncthing unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="95"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="110"/>
        <location filename="../settings/systemdoptionpage.ui" line="165"/>
        <location filename="../settings/systemdoptionpage.ui" line="254"/>
        <location filename="../settings/settingsdialog.cpp" line="1526"/>
        <location filename="../settings/settingsdialog.cpp" line="1535"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="125"/>
        <source>Current status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="178"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="195"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="214"/>
        <source>Unit file state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="267"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="284"/>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="82"/>
        <source>System unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1424"/>
        <source>Reload all unit files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1462"/>
        <source>It is not possible to show the start/stop button for the systemd service and the internal launcher at the same time. The systemd service precedes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1468"/>
        <source>It is not possible to consider the systemd service and the internal launcher for reconnects at the same time. The systemd service precedes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1499"/>
        <source>specified unit is either inactive or doesn&apos;t exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1521"/>
        <source>since </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::TextViewDialog</name>
    <message>
        <location filename="../misc/textviewdialog.cpp" line="61"/>
        <location filename="../misc/textviewdialog.cpp" line="70"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::WebPage</name>
    <message>
        <location filename="../webview/webpage.cpp" line="492"/>
        <source>Select path for Syncthing directory …</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::WebViewDialog</name>
    <message>
        <location filename="../webview/webviewdialog.cpp" line="46"/>
        <source>Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::WelcomeWizardPage</name>
    <message>
        <location filename="../settings/wizard.cpp" line="448"/>
        <source>Welcome to Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="449"/>
        <source>It looks like you&apos;re launching Syncthing Tray for the first time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="450"/>
        <source>You must configure how to connect to Syncthing and how to launch Syncthing (if that&apos;s wanted) when using Syncthing Tray the first time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="453"/>
        <source>Wizard&apos;s start page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="454"/>
        <source>This wizard will help you configuring Syncthing Tray.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="459"/>
        <source>Start guided setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="461"/>
        <source>Allows to configure Syncthing Tray automatically for the local Syncthing instance and helps you starting Syncthing if wanted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="469"/>
        <source>Configure connection and launcher settings manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="471"/>
        <source>Head back to settings to configure connection and launcher manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="474"/>
        <source>Note that the connection settings allow importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="490"/>
        <source>Show Syncthing&apos;s documentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="491"/>
        <source>It contains general information about configuring Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="497"/>
        <source>Show Syncthing Tray&apos;s README</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="498"/>
        <source>It contains documentation about this GUI integration specifically.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::Wizard</name>
    <message>
        <location filename="../settings/wizard.cpp" line="73"/>
        <source>Setup wizard - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="217"/>
        <source>The internal launcher has not been initialized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="229"/>
        <source>The service handler has not been initialized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="262"/>
        <source>Unable to locate Syncthing config file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="264"/>
        <source>Located Syncthing config file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="266"/>
        <source>Syncthing config file looks ok.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="268"/>
        <source>Syncthing config file looks invalid/incomplete.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="271"/>
        <source>Syncthing configuration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="279"/>
        <source>Could connect to Syncthing under: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="280"/>
        <source>Syncthing version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="281"/>
        <source>Syncthing device ID: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="282"/>
        <source>Syncthing status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="284"/>
        <source>Additional Syncthing status info: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="319"/>
        <source>Autostart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="320"/>
        <source>Currently %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="320"/>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="320"/>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="322"/>
        <source>Points to &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="364"/>
        <source>The Syncthing process exited prematurely. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="377"/>
        <source>The Syncthing service stopped prematurely. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="401"/>
        <source>Ran into timeout while waiting for Syncthing to create config file. Maybe Syncthing created its config file under an unexpected location. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="412"/>
        <source>Checkout Syncthing&apos;s log for details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="416"/>
        <source> It can be accessed within the &lt;a href=&quot;openLauncherSettings&quot;&gt;launcher settings&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="421"/>
        <source> It is normally written to the system journal (and can be accessed via e.g. journalctl).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="289"/>
        <source>API connection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="292"/>
        <source>API connection errors:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="299"/>
        <source>State of user unit file &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="300"/>
        <source>State of system unit file &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="297"/>
        <source>Systemd:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="287"/>
        <source>Could NOT connect to Syncthing under: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="303"/>
        <source>No available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="309"/>
        <source>Could test-launch Syncthing successfully, exit code: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="310"/>
        <source>Syncthing version returned from test-launch: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="312"/>
        <source>Unable to test-launch Syncthing: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="314"/>
        <source>Built-in Syncthing available: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="314"/>
        <source>yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="314"/>
        <source>no</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="315"/>
        <source>Launcher:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="330"/>
        <source>Details from setup detection - </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings::Connection</name>
    <message>
        <location filename="../settings/settings.cpp" line="667"/>
        <source>Backup of %1 (created by wizard)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings::restore</name>
    <message>
        <location filename="../settings/settings.cpp" line="331"/>
        <source>Unable to load certificate &quot;%1&quot; when restoring settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
